        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 31 <strong>control</strong><br>0,1,3,4,5,7,9,11,12,13,15,17,18,20,21,23,24,25,26,27,28,32,33,34,37,38,43,45,47,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 20 <br>2,6,8,10,14,16,19,22,29,30,31,35,36,39,40,41,42,44,46,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 31 <strong>control</strong><br>0,1,3,4,5,7,9,11,12,13,15,17,18,20,21,23,24,25,26,27,28,32,33,34,37,38,43,45,47,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 20 <br>2,6,8,10,14,16,19,22,29,30,31,35,36,39,40,41,42,44,46,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 31 <strong>control</strong><br>0,1,3,4,5,7,9,11,12,13,15,17,18,20,21,23,24,25,26,27,28,32,33,34,37,38,43,45,47,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 20 <br>2,6,8,10,14,16,19,22,29,30,31,35,36,39,40,41,42,44,46,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 31 <strong>control</strong><br>0,1,3,4,5,7,9,11,12,13,15,17,18,20,21,23,24,25,26,27,28,32,33,34,37,38,43,45,47,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 20 <br>2,6,8,10,14,16,19,22,29,30,31,35,36,39,40,41,42,44,46,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>15</strong> miembros: 31 <strong>control</strong><br>0,1,3,4,5,7,9,11,12,13,15,17,18,20,21,23,24,25,26,27,28,32,33,34,37,38,43,45,47,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260517 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>29</strong> miembros: 20 <br>2,6,8,10,14,16,19,22,29,30,31,35,36,39,40,41,42,44,46,48';}
}
